@@ -27,7 +27,7 @@ import socket
 
 
 # The current version of duplicity
-version = "0.7.18.2"
+version = "0.7.19"
 
 # Prefix for all files (appended before type-specific prefixes)
 file_prefix = ""
@@ -225,6 +225,9 @@ imap_full_address = False
 # Can be changed with a command line argument.
 imap_mailbox = "INBOX"
 
+# Sync all metadata by default
+metadata_sync_mode = "full"
+
 # Whether the old filename format is in effect.
 old_filenames = False
 
